@@ -5,9 +5,11 @@
 #include <unistd.h>
 #include <time.h>
 
-#include <QtTest>
 #include <QEventLoop>
 #include <QLocale>
+#include <QRandomGenerator64>
+#include <QtTest>
+
 #include <util/log.h>
 #include <util/error.h>
 #include <util/functions.h>
@@ -16,6 +18,7 @@
 #include <datachecker/singledatachecker.h>
 #include <datachecker/multidatachecker.h>
 #include <testlib/dummytorrentcreator.h>
+
 #include <boost/concept_check.hpp>
 
 
@@ -26,7 +29,7 @@ const bt::Uint64 TEST_FILE_SIZE = 15 * 1024 * 1024;
 bt::Uint64 RandomSize(bt::Uint64 min_size, bt::Uint64 max_size)
 {
     bt::Uint64 r = max_size - min_size;
-    return min_size + qrand() % r;
+    return min_size + QRandomGenerator64::global()->generate() % r;
 }
 
 class DataCheckerTest : public QEventLoop
@@ -35,13 +38,12 @@ class DataCheckerTest : public QEventLoop
 
 public:
 
-private slots:
+private Q_SLOTS:
     void initTestCase()
     {
         QLocale::setDefault(QLocale("main"));
         bt::InitLibKTorrent();
         bt::InitLog("datacheckertest.log", false, true);
-        qsrand(time(0));
     }
 
     void testSingleFile()
@@ -52,26 +54,20 @@ private slots:
         QVERIFY(creator.createSingleFileTorrent(TEST_FILE_SIZE, "test.avi"));
 
         Out(SYS_GEN | LOG_DEBUG) << "Created " << creator.torrentPath() << endl;
-        try
-        {
+        try {
             tc.init(0, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0", creator.tempPath() + "data/");
             tc.createFiles();
-        }
-        catch (bt::Error& err)
-        {
+        } catch (bt::Error& err) {
             Out(SYS_GEN | LOG_DEBUG) << "Failed to load torrent: " << creator.torrentPath() << endl;
             QFAIL("Torrent load failure");
         }
 
         SingleDataChecker dc(0, tc.getStats().total_chunks);
-        try
-        {
+        try {
             QString dnd = tc.getTorDir() + "dnd" + bt::DirSeparator();
             dc.check(tc.getStats().output_path, tc.getTorrent(), dnd, tc.downloadedChunksBitSet());
             QVERIFY(dc.getResult().allOn());
-        }
-        catch (bt::Error& err)
-        {
+        } catch (bt::Error& err) {
             Out(SYS_GEN | LOG_DEBUG) << "Datacheck failed: " << err.toString() << endl;
             QFAIL("Torrent load failure");
         }
@@ -91,26 +87,20 @@ private slots:
         QVERIFY(creator.createMultiFileTorrent(files, "movies"));
 
         Out(SYS_GEN | LOG_DEBUG) << "Created " << creator.torrentPath() << endl;
-        try
-        {
+        try {
             tc.init(0, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0", creator.tempPath() + "data/");
             tc.createFiles();
-        }
-        catch (bt::Error& err)
-        {
+        } catch (bt::Error& err) {
             Out(SYS_GEN | LOG_DEBUG) << "Failed to load torrent: " << creator.torrentPath() << endl;
             QFAIL("Torrent load failure");
         }
 
         MultiDataChecker dc(0, tc.getStats().total_chunks);
-        try
-        {
+        try {
             QString dnd = tc.getTorDir() + "dnd" + bt::DirSeparator();
             dc.check(tc.getStats().output_path, tc.getTorrent(), dnd, tc.downloadedChunksBitSet());
             QVERIFY(dc.getResult().allOn());
-        }
-        catch (bt::Error& err)
-        {
+        } catch (bt::Error& err) {
             Out(SYS_GEN | LOG_DEBUG) << "Datacheck failed: " << err.toString() << endl;
             QFAIL("Torrent check failure");
         }
@@ -130,30 +120,23 @@ private slots:
         QVERIFY(creator.createMultiFileTorrent(files, "movies"));
 
         Out(SYS_GEN | LOG_DEBUG) << "Created " << creator.torrentPath() << endl;
-        try
-        {
+        try {
             tc.init(0, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0", creator.tempPath() + "data/");
             tc.createFiles();
-        }
-        catch (bt::Error& err)
-        {
+        } catch (bt::Error& err) {
             Out(SYS_GEN | LOG_DEBUG) << "Failed to load torrent: " << creator.torrentPath() << endl;
             QFAIL("Torrent load failure");
         }
 
-        for (Uint32 file = 0; file < tc.getNumFiles(); file++)
-        {
+        for (Uint32 file = 0; file < tc.getNumFiles(); file++) {
             const bt::TorrentFileInterface& fi = tc.getTorrentFile(file);
             MultiDataChecker dc(fi.getFirstChunk(), fi.getLastChunk());
-            try
-            {
+            try {
                 QString dnd = tc.getTorDir() + "dnd" + bt::DirSeparator();
                 dc.check(tc.getStats().output_path, tc.getTorrent(), dnd, tc.downloadedChunksBitSet());
                 for (Uint32 i = 0; i < tc.getStats().total_chunks; i++)
                     QVERIFY(dc.getResult().get(i) == (i >= fi.getFirstChunk() && i <= fi.getLastChunk()));
-            }
-            catch (bt::Error& err)
-            {
+            } catch (bt::Error& err) {
                 Out(SYS_GEN | LOG_DEBUG) << "Datacheck failed: " << err.toString() << endl;
                 QFAIL("Torrent check failure");
             }
